==> pollen-business-1.0.1-sources.jar: org/chorem/pollen/business/persistence/PersonToList.java <==
/* *##%
 Copyright (C) 2009 Pollen
 *##%*/
package org.chorem.pollen.business.persistence;

import org.nuiton.topia.persistence.SearchFields;
import org.nuiton.topia.persistence.TopiaEntity;

@SearchFields (
  txtFields={"hasVoted"},
  numFields={"weight"}
)        
public interface PersonToList extends TopiaEntity {

    public static final String WEIGHT = "weight";

    public static final String HAS_VOTED = "hasVoted";

    public static final String VOTING_LIST = "votingList";

    public static final String POLL_ACCOUNT = "pollAccount";

    /**
     * @param weight La valeur de l'attribut weight à positionner.
     */
    public void setWeight(double weight);

    /**
     * @return La valeur de l'attribut weight.
     */
    public double getWeight();

    /**
     * @param hasVoted La valeur de l'attribut hasVoted à positionner.
     */
    public void setHasVoted(java.lang.String hasVoted);

    /**
     * @return La valeur de l'attribut hasVoted.
     */
    public java.lang.String getHasVoted();

    /**
     * @param value La valeur de l'attribut votingList à positionner.
     */
    public void setVotingList(org.chorem.pollen.business.persistence.VotingList value);

    /**
     * @return La valeur de l'attribut votingList.
     */
    public org.chorem.pollen.business.persistence.VotingList getVotingList();

    /**
     * @param value La valeur de l'attribut pollAccount à positionner.
     */
    public void setPollAccount(org.chorem.pollen.business.persistence.PollAccount value);

    /**
     * @return La valeur de l'attribut pollAccount.
     */
    public org.chorem.pollen.business.persistence.PollAccount getPollAccount();

} //PersonToList

==> pollen-business-1.2.3-sources.jar: org/chorem/pollen/business/persistence/PersonToList.java <==
/* *##%
 Copyright (C) 2009 Pollen
 *##%*/
package org.chorem.pollen.business.persistence;

import org.nuiton.topia.persistence.SearchFields;
import org.nuiton.topia.persistence.TopiaEntity;

@SearchFields (
  numFields={"weight"},
  boolFields={"hasVoted"}
)        
public interface PersonToList extends TopiaEntity {

    public static final String WEIGHT = "weight";

    public static final String HAS_VOTED = "hasVoted";

    public static final String VOTING_LIST = "votingList";

    public static final String POLL_ACCOUNT = "pollAccount";

    /**
     * @param weight La valeur de l'attribut weight à positionner.
     */
    public void setWeight(java.lang.Double weight);

    /**
     * @return La valeur de l'attribut weight.
     */
    public java.lang.Double getWeight();

    /**
     * @param hasVoted La valeur de l'attribut hasVoted à positionner.
     */
    public void setHasVoted(java.lang.Boolean hasVoted);

    /**
     * @return La valeur de l'attribut hasVoted.
     */
    public java.lang.Boolean getHasVoted();

    /**
     * @param value La valeur de l'attribut votingList à positionner.
     */
    public void setVotingList(org.chorem.pollen.business.persistence.VotingList value);

    /**
     * @return La valeur de l'attribut votingList.
     */
    public org.chorem.pollen.business.persistence.VotingList getVotingList();

    /**
     * @param value La valeur de l'attribut pollAccount à positionner.
     */
    public void setPollAccount(org.chorem.pollen.business.persistence.PollAccount value);

    /**
     * @return La valeur de l'attribut pollAccount.
     */
    public org.chorem.pollen.business.persistence.PollAccount getPollAccount();

} //PersonToList
